close all

ccdX = 640;
ccdY = 480;
magnification = 40;
pixelSize = 7.4e-6 / magnification;
particleDiameter = 5e-6;
numberOfParticles = 5;

noise = 1e-3;
particlePeakIntensity = 1e2;

particleRadiusPixels = particleDiameter / pixelSize;

% generate random particle centroids
centroids = rand( numberOfParticles, 2 );
centroids(:, 1) = centroids(:, 1) * ccdY;
centroids(:, 2) = centroids(:, 2) * ccdX;

intensity = rand(1, numberOfParticles);

particleImage = SimulatedFluorescenntParticleImage(centroids, intensity, particleRadiusPixels, [ccdY ccdX]);

threshold = graythresh( particleImage );

figure(1);
imagesc(particleImage);
axis off;
colormap gray;
title('Synthetic Particle Image Without Noise');

[centroidList, labels, numberOfParticles] = FindCentroids(particleImage, 0.1);
    
figure(2);
imagesc(labels);
title('Label Matrix');

figure(3);
imagesc(particleImage);
axis off;
colormap gray;
hold on
for ii=1:numberOfParticles
    plot(centroidList(ii, 1), centroidList(ii, 2), 'rx', 'LineWidth', 2);
end
title('Noise Free Image with Centroids');

% add noise to the image
noisyParticleImage = poissrnd(round(particlePeakIntensity * particleImage))/particlePeakIntensity + noise * randn(ccdY, ccdX);

threshold = graythresh( particleImage );

figure(4);
imagesc(noisyParticleImage);
axis off;
colormap gray;
title('Synthetic Particle Image with Added Noise');

[centroidList, labels, numberOfParticles] = FindCentroids(noisyParticleImage, 0.1);
 

figure(5);
imagesc(labels);
title('Label Matrix for Noisy Image');


figure(6);
imagesc(noisyParticleImage);
axis off;
colormap gray;
hold on
for ii=1:numberOfParticles
    plot(centroidList(ii, 1), centroidList(ii, 2), 'rx', 'LineWidth', 2);
end
title('Noisy Image with Centroids');
